package info.textgrid.middleware;

import java.io.IOException;
import org.elasticsearch.action.get.GetRequest;
import org.elasticsearch.action.get.GetResponse;
import org.elasticsearch.client.RequestOptions;
import org.elasticsearch.common.Strings;
import org.elasticsearch.search.fetch.subphase.FetchSourceContext;
import info.textgrid.middleware.oaipmh.ListMetadataFormatsType;
import info.textgrid.middleware.oaipmh.MetadataFormatType;

/**
 *
 */
public class MetadataFormatListDelivererTG extends MetadataFormatListDelivererAbs {

  /**
   * 
   */
  public MetadataFormatListDelivererTG() {
    //
  }

  /*
   * (non-Javadoc)
   * 
   * @see
   * info.textgrid.middleware.MetadataFormatListDelivererInterface#setMetadataFormatList(java.lang.
   * String)
   */
  public ListMetadataFormatsType setMetadataFormatList(String id) {

    String[] includes = new String[] {TGConstants.URI};
    String[] excludes = Strings.EMPTY_ARRAY;
    FetchSourceContext fetchSourceContext = new FetchSourceContext(true, includes, excludes);

    ListMetadataFormatsType lmft = new ListMetadataFormatsType();
    MetadataFormatType mft = new MetadataFormatType();
    MetadataFormatType openAireMetadataFormat = new MetadataFormatType();

    GetRequest getRequest = new GetRequest(OAI_ESClient.getEsIndex(), OAI_ESClient.getEsType(),
        id.replace("textgrid:", "")).fetchSourceContext(fetchSourceContext);

    GetResponse tgObject = null;
    try {
      tgObject = OAI_ESClient.getEsClient().get(getRequest, RequestOptions.DEFAULT);
    } catch (IOException e) {
      // TODO Auto-generated catch block
      e.printStackTrace();
    }

    if (tgObject.isExists()) {
      setIdExist(true);
      mft.setMetadataPrefix(OAIPMHUtilities.OAIDC_PREFIX);
      mft.setMetadataNamespace(OAIPMHUtilities.OAIDC_NAMESPACE);
      mft.setSchema(OAIPMHUtilities.OAIDC_SCHEMA_LOCATION);

      openAireMetadataFormat.setMetadataNamespace(OAIPMHUtilities.OPEN_AIRE_NAMESPACE);
      openAireMetadataFormat.setMetadataPrefix(TGConstants.METADATA_OPENAIRE_PREFIX);
      openAireMetadataFormat.setSchema(OAIPMHUtilities.OPEN_AIRE_SCHEMA_LOCATION);

      lmft.getMetadataFormat().add(mft);
      lmft.getMetadataFormat().add(openAireMetadataFormat);

    } else {
      setIdExist(false);
      lmft = null;
    }

    return lmft;
  }

  /*
   * (non-Javadoc)
   * 
   * @see info.textgrid.middleware.MetadataFormatListDelivererAbs#setMetadataFormatList()
   */
  public ListMetadataFormatsType setMetadataFormatList() {

    ListMetadataFormatsType result = new ListMetadataFormatsType();

    // Add default metadata format (oai_dc).
    MetadataFormatType mft = new MetadataFormatType();
    mft.setMetadataPrefix(OAIPMHUtilities.OAIDC_PREFIX);
    mft.setMetadataNamespace(OAIPMHUtilities.OAIDC_NAMESPACE);
    mft.setSchema(OAIPMHUtilities.OAIDC_SCHEMA_LOCATION);
    result.getMetadataFormat().add(mft);

    // Add metadata format for IDIOM.
    MetadataFormatType mftIdiomMets = new MetadataFormatType();
    mftIdiomMets.setMetadataPrefix(TGConstants.METADATA_IDIOM_PREFIX);
    mftIdiomMets.setMetadataNamespace(OAIPMHUtilities.METS_NAMESPACE);
    mftIdiomMets.setSchema(OAIPMHUtilities.METS_SCHEMA_LOCATION);
    result.getMetadataFormat().add(mftIdiomMets);

    // Add metadata format for OPEN AIRE.
    MetadataFormatType mftOpenAire = new MetadataFormatType();
    mftOpenAire.setMetadataNamespace(OAIPMHUtilities.OPEN_AIRE_NAMESPACE);
    mftOpenAire.setMetadataPrefix(TGConstants.METADATA_OPENAIRE_PREFIX);
    mftOpenAire.setSchema(OAIPMHUtilities.OPEN_AIRE_SCHEMA_LOCATION);
    result.getMetadataFormat().add(mftOpenAire);

    return result;
  }

}
